@@ -24,19 +24,7 @@ NULL
 #' @examples
 #' PolygonArea(x, y)
 #' @export
-PolygonArea <- function(x, y = NULL, positive = TRUE) {
-  xy <- xy.coords(x, y)
-  x <- c(xy$x, xy$x[1])
-  y <- c(xy$y, xy$y[1])
-  area <- (sum((xy$x * y[-1])) - sum((xy$y * x[-1]))) / 2
-
-  # Return:
-  if (isTRUE(positive)) {
-    abs(area)
-  } else {
-    area
-  }
-}
+PolygonArea <- PlotTools::PolygonArea
 
 #' @describeIn Polygon-Geometry Locate the centre of a polygon
 #' @importFrom grDevices xy.coords
@@ -45,19 +33,7 @@ PolygonArea <- function(x, y = NULL, positive = TRUE) {
 #' @examples
 #' points(PolygonCentre(x, y), pch = 3, cex = 2)
 #' @export
-PolygonCentre <- function(x, y = NULL) {
-  xy <- xy.coords(x, y)
-  area <- PolygonArea(xy, positive = FALSE)
-
-  x <- xy$x
-  x1 <- c(x[-1], x[1])
-  y <- xy$y
-  y1 <- c(y[-1], y[1])
-  prod <- (x * y1) - (x1 * y)
-
-  cbind(x = sum((x + x1) * prod),
-        y = sum((y + y1) * prod)) / (6 * area)
-}
+PolygonCentre <- PlotTools::PolygonCentre
 
 #' @rdname Polygon-Geometry
 #' @export
@@ -78,19 +54,4 @@ PolygonCenter <- PolygonCentre
 #' # Negative values shrink the polygon
 #' polygon(GrowPolygon(x, y, -1), border = "red")
 #' @export
-GrowPolygon <- function(x, y = NULL, buffer = 0) {
-  xy <- xy.coords(x, y)
-  cent <- PolygonCentre(x, y)
-
-  x0 <- xy$x - cent[, "x"]
-  y0 <- xy$y - cent[, "y"]
-  hyp <- sqrt((x0 * x0) + (y0 * y0))
-  stretch <- (hyp + buffer) / hyp
-  x1 <- x0 * stretch
-  y1 <- y0 * stretch
-
-  xy$x <- x1 + cent[, "x"]
-  xy$y <- y1 + cent[, "y"]
-
-  xy
-}
+GrowPolygon <- PlotTools::GrowPolygon
